# analyse of the fishlabel data

# load useful libraries
library(gplots)
library(multcomp)


# read the data
fish=read.table("finaldata-4.csv", h=T, na.string="na")
attach(fish)

# check the data input
print(summary(fish))
#fish$price=as.numeric(levels(fish$price))[fish$price]

# change the french name of commercial names catagories to their english equivalent

spNameEng=as.character(fish$spName)
spNameFr=as.character(fish$spName)

spNameEng[spNameEng=="loupdemer"]="wolffish"
spNameEng[spNameEng=="sabrenoir"]="black scabardfish"
spNameEng[spNameEng=="raie"]="ray"
spNameEng[spNameEng=="grenadier"]="grenadier"
spNameEng[spNameEng=="sole"]="sole"
spNameEng[spNameEng=="bar"]="sea bass"
spNameEng[spNameEng=="thon"]="tuna"
spNameEng[spNameEng=="cabillaud"]="cod"
spNameEng[spNameEng=="lotte"]="angler fish"
spNameEng[spNameEng=="pagre"]="seabream"
spNameEng[spNameEng=="limande"]="limanda"
spNameEng[spNameEng=="lieujaune"]="atlantic pollock"
spNameEng[spNameEng=="eglefin"]="haddock"
spNameEng[spNameEng=="merlan"]="whiting"
spNameEng[spNameEng=="merlu"]="hake"
spNameEng[spNameEng=="colin"]="colin" # translation not possible : no english equivalent
spNameEng[spNameEng=="lingue"]="ling"
spNameEng[spNameEng=="rouget"]="red mullet"
spNameEng[spNameEng=="panga"]="shark catfish"
spNameEng[spNameEng=="lieunoir"]="pollock"
spNameEng[spNameEng=="requin"]="shark"
spNameEng[spNameEng=="fletan"]="halibut"
spNameEng[spNameEng=="saumon"]="salmon"
spNameEng[spNameEng=="maquereau"]="mackerel"
spNameEng[spNameEng=="turbot"]="turbot"
spNameEng[spNameEng=="sebaste"]="golden redfish"
spNameEng[spNameEng=="dorade"]="dorade" # translation not possible : no english equivalent
spNameEng[spNameEng=="alaska"]="alaska pollock"
spNameEng[spNameEng=="rouge"]="bluefin tuna"
spNameEng[spNameEng=="espadon"]="swordfish"

detach(fish)

# change the names of shop types by their english equivalents

fish$shop=as.character(fish$shop)

fish$shop[fish$shop=="poiss"]="fishmonger"
fish$shop[fish$shop=="rest"]="restaurants"
fish$shop[fish$shop=="super"]="supermarket"


# change the name of the types of products by their english equivalents

fish$soldAs=as.character(fish$soldAs)

fish$soldAs[fish$soldAs=="rest"]="restaurant meal"
fish$soldAs[fish$soldAs=="surg"]="deep-frozen filet"
fish$soldAs[fish$soldAs=="plat"]="industrial meal"
fish$soldAs[fish$soldAs=="filet"]="fresh filet"

# save the modifications

fish$soldAs=as.factor(fish$soldAs)
fish$shop=as.factor(fish$shop)
fish$spName=as.factor(spNameEng)
attach(fish)


# plot the distribution of samples per declared species and shop types

par(mar=c(5,8,4,2)) 
barplot(table(list(shop, spName)), horiz=T, las=1, col=c("darkblue","blue", "lightblue"), xlab="number of samples")
legend(x=80, y=30, legend=c("fishmonger","restaurant","supermarket"), fill=c("darkblue","blue","lightblue"))


# name of the species for which agt least one substitution was observed
subst=table(misLab, spName)[2,][which(table(misLab, spName)[2,]>0)]
print(paste(subst, "substitution observed for", names(subst)))

# calculate the global rate of substitution
numNA=length(which(is.na(misLab)))


# 95% ci interval of the rate of substitution


print("####################################")
print(paste("global rate=", 100*round(1-prop.test(table(misLab))$estimate,4)))
print(paste("ci(95%)=", 100*round(1-prop.test(table(misLab))$conf.int[[2]],3), "-", 100*round(1-prop.test(table(misLab))$conf.int[[1]],3)))

print("####################################")

do.this=T

if (do.this==T) {


# choose the best model

# complete model
model=glm(misLab~spName*shop*protocole*soldAs, family=binomial(link="logit"))
anova(model, test="Chisq")

# impact of the species and the mode of commercialisation (soldAs)
# keep only the significant variables
model0=glm(misLab~spName*soldAs, family=binomial(link="logit"))
anova(model0, test="Chisq")

# interaction not significant
model1=glm(misLab~spName+soldAs, family=binomial(link="logit"))
anova(model1, test="Chisq")


# total number of observed species in the dataset
length(unique(realSp))

# analyse per species, post hoc test ?

# decrease the number of species by creating a category for all the species with less than 10 samples
# also keep red tune because this species was detected as having a high fraud rate
listNames= names(which(table(spName)>=10))
spName2=NULL
for (i in 1:length(spName)) {
	if (any(listNames==as.character(spName[i]))) {spName2[i]=as.character(spName[i])
	} else spName2[i]="other" 
}
spName2=as.factor(spName2)

# run the statistical model again
model1=glm(misLab~spName2+soldAs, family=binomial(link="logit"))
print(anova(model1, test="Chisq"))

print(summary(glht(model1, mcp(spName2="Tukey"))))

# significant differences only due to red tuna ("rouge") with cod ("cabillaud"), tuna ("thon") and other species ("other")
# so significant effect of species due to blue fin tuna

# plot the substitutions cases per species with 10 or more samples
X11()
par(mar=c(5,6,4,2)) 
barplot(table(misLab,spName2), horiz=T, las=1, col=c("green","red"), main="substitution per species", xlab="number of samples")
legend(x=80, y=10, legend=c("substitution","correct labelling"), fill=c("red","green"))

} ## END OF THE EXCLUSION IF


# fraud rate per species (with more than 10 samples)
misRate=round(table(misLab, spName2)[2,]*100/colSums(table(misLab, spName2)),1)

# calculate the confidence interval for each species
lower=NULL
upper=NULL
for (i in names(misRate)){
	if(dim(table(misLab[spName2==i]))==1) {	
		lower=append(lower,NA)
		upper=append(upper,NA)
		} else {
		dum=prop.test(table(misLab[spName2==i]))
		lower=append(lower,1-dum$conf.int[1])
		upper=append(upper,1-dum$conf.int[2])
		}
	}


print(lower*100)
print(upper*100)
print(misRate)

# plot the rate of fraud per species
X11()
par(mar=c(6,6,4,2))
labs=barplot2(misRate, plot.ci=T, ci.l=lower*100, ci.u=upper*100, ylab="substitution rate (%)", xaxt="n")
text(cex=1, x=labs, y=-3, names(misRate), xpd=TRUE, srt=60, adj=1)
abline(h=ci.freq(misLab)[[1]][2]*100, lty=2, col="red")

# per type of product sold
misRateType=round(table(misLab, soldAs)[2,]*100/colSums(table(misLab, soldAs)),1)
lower=NULL
upper=NULL
for (i in names(misRateType)){
        if(dim(table(misLab[soldAs==i]))==1) {
                lower=append(lower,NA)
                upper=append(upper,NA)
                } else {
                dum=prop.test(table(misLab[soldAs==i]))
                lower=append(lower,1-dum$conf.int[1])
                upper=append(upper,1-dum$conf.int[2])
                }
        }

# plot the substitutions cases per type of product
X11()
par(mar=c(5,8,4,2))
barplot(table(misLab,soldAs), horiz=T, las=1, col=c("green","red"), xlab="number of samples")
legend(x=110, y=4, legend=c("substitution","correct labelling"), fill=c("red","green"))

# plot the rate of fraud per type of product
X11()
barplot2(misRateType, plot.ci=T, ci.l=lower*100, ci.u=upper*100, ylab="substitution rate (%)")
abline(h=ci.freq(misLab)[[1]][2]*100, lty=2, col="red")



# analysis of the price

# by categories : restaurants first...

dataRest=fish[shop=="restaurants",]
modelPriceRest=glm(misLab~spName*protocole*price, family=binomial(link="logit"), data=dataRest)

print(anova(modelPriceRest, test="Chisq"))

# no effect of the price (no effect of any variable at all...)

# fish shop now...

dataPoiss=fish[shop=="fishmonger",]
modelPriceFishmonger=glm(misLab~spName*protocole*price, family=binomial(link="logit"), data=dataPoiss)

print(anova(modelPriceFishmonger, test="Chisq"))


# no difference among groups for fish shop too.








# JBC - INSERM U1001 - feb 2014



